@@ -84,8 +84,9 @@ do_destroy_afinter(struct log_handler *c,
 		   struct syslog_config *cfg, 
 		   struct persistent_config *persistent)
 {
-	if (cfg == assigned_configuration)
+	if (cfg == assigned_configuration) {
 		assigned_configuration = NULL;
+	}
 }
 
 struct log_source_driver *make_afinter_source(void)
