@@ -144,7 +144,7 @@ struct read_handler *make_log_reader(UINT32 userecv, struct log_handler *next)
 
 /* source_group */
 
-static struct ol_string *get_source_hostname(struct address_info *a)
+static struct ol_string *get_source_hostname(struct address_info *a, int usedns, int usefqdn)
 {
 	struct ol_string *name;
 	static struct ol_string *hostname = NULL;
@@ -154,14 +154,16 @@ static struct ol_string *get_source_hostname(struct address_info *a)
 	        struct hostent *hp;
 		char *hname, *p;
 
-		hp = gethostbyaddr((char *) &(inet_addr->sa.sin_addr), sizeof(struct in_addr), AF_INET);
+		hp = usedns ? NULL : gethostbyaddr((char *) &(inet_addr->sa.sin_addr), sizeof(struct in_addr), AF_INET);
 		if (!hp) {
 			return ol_string_use(inet_addr->ip);
 		}
 		else {
 			hname = hp->h_name;
-			p = strchr(hname, '.');
-			if (p) *p = 0;
+			if (!usefqdn) {
+				p = strchr(hname, '.');
+				if (p) *p = 0;
+			}
 		}
 		name = c_format_cstring("%z", hname);
 	}
@@ -180,11 +182,14 @@ static struct ol_string *get_source_hostname(struct address_info *a)
 static void do_add_source_name(struct log_handler *c, struct log_info *logmsg)
 {
 	CAST(log_source_group, self, c);
-	struct ol_string *name = get_source_hostname(logmsg->saddr);
+	struct ol_string *name = get_source_hostname(logmsg->saddr, self->use_dns, self->use_fqdn);
 
-	assert(self->super.next);
+	if (!self->super.next) {
+		log_info_free(logmsg);
+		return;
+	}
 	logmsg->source = c;
-	if (self->long_hostnames) {
+	if (self->chain_hostnames) {
 		if (logmsg->flags & LF_LOCAL) {
 			/* local */
 			ol_string_free(logmsg->host);
@@ -216,7 +221,9 @@ static int do_init_group(struct log_handler *c, struct syslog_config *cfg, struc
 	
 	struct log_source_driver *drv;
 	
-	self->long_hostnames = cfg->long_hostnames;
+	self->chain_hostnames = cfg->chain_hostnames;
+	self->use_dns = cfg->use_dns;
+	self->use_fqdn = cfg->use_fqdn;
 	res = 0;
 	for (drv = self->drivers; drv; drv = drv->next_driver) {
 		res = LOG_HANDLER_INIT(drv, cfg, persistent);
@@ -232,7 +239,6 @@ static void do_destroy_group(struct log_handler *c, struct syslog_config *cfg, s
 	
 	struct log_source_driver *drv;
 	
-	self->long_hostnames = cfg->long_hostnames;
 	for (drv = self->drivers; drv; drv = drv->next_driver) {
 		if (drv->super.super.destroy)
 			LOG_HANDLER_DESTROY(drv, cfg, persistent);
